Class: RBarman::WalFiles
- Inherits:
-
Array
- Object
- Array
- RBarman::WalFiles
- Defined in:
- lib/rbarman/wal_files.rb
Overview
An Array of WalFile
Class Method Summary collapse
-
.by_id(server, backup_id) ⇒ WalFiles
Instructs the underlying (barman) command to get all wal files for a specific backup id.
Instance Method Summary collapse
-
#initialize(other = nil) ⇒ WalFiles
constructor
Initializes a new Array of WalFile.
Constructor Details
#initialize(other = nil) ⇒ WalFiles
Initializes a new Array of RBarman::WalFile
9 10 11 |
# File 'lib/rbarman/wal_files.rb', line 9 def initialize(other=nil) self.concat(other) if !other.nil? and other.is_a? Array end |
Class Method Details
.by_id(server, backup_id) ⇒ WalFiles
Instructs the underlying (barman) command to get all wal files for a specific backup id
17 18 19 20 |
# File 'lib/rbarman/wal_files.rb', line 17 def self.by_id(server, backup_id) cmd = CliCommand.new return WalFiles.new(cmd.wal_files(server, backup_id)) end |